BounceV1ListEntry

Struct BounceV1ListEntry 

pub struct BounceV1ListEntry {
    pub id: Uuid,
    pub campaign: Option<String>,
    pub tenant: Option<String>,
    pub domain: Option<String>,
    pub routing_domain: Option<String>,
    pub reason: String,
    pub duration: Duration,
    pub bounced: HashMap<String, usize>,
    pub total_bounced: usize,
}

Fields

id: Uuid

The id of this bounce rule. Corresponds to the id field returned by the originating request that set up the bounce, and can be used to identify this particular entry if you wish to delete it later.

campaign: Option<String>

The campaign field of the original request, if any.

tenant: Option<String>

The tenant field of the original request, if any.

domain: Option<String>

The domain field of the original request, if any.

routing_domain: Option<String>

The routing_domain field of the original request, if any.

reason: String

The reason field of the original request

duration: Duration

The time remaining until this entry expires and is automatically removed.

bounced: HashMap<String, usize>

A map of queue name to number of bounced messages that were processed by this entry since it was created.

total_bounced: usize

The sum of the number of bounced messages reported by the bounced field.