pub struct InspectMessageV1Request {
pub id: SpoolId,
pub want_body: bool,
}Fields
id: SpoolIdThe spool identifier for the message whose information is being requested
want_body: boolIf true, return the message body in addition to the metadata