pub struct MachineInfoV1 {Show 15 fields
pub node_id: String,
pub hostname: String,
pub mac_address: String,
pub num_cores: usize,
pub kernel_version: Option<String>,
pub platform: String,
pub distribution: String,
pub os_version: String,
pub total_memory_bytes: u64,
pub container_runtime: Option<String>,
pub cpu_brand: String,
pub fingerprint: String,
pub online_since: DateTime<Utc>,
pub process_kind: String,
pub version: String,
}Fields
node_id: StringThe NodeID of the system
hostname: StringThe hostname of the system, as reported by gethostname(2)
mac_address: StringThe MAC address of the primary, non-loopback, network interface
num_cores: usizeThe number of available CPUs as reported by https://docs.rs/num_cpus/latest/num_cpus/fn.get.html
kernel_version: Option<String>The kernel version
platform: StringIdentifies the running platform
distribution: StringThe OS distribution
os_version: StringThe OS version (which often includes the distribution)
total_memory_bytes: u64Total physical memory installed in the instance
container_runtime: Option<String>If we detected that we’re running in a container, the name of the container runtime
cpu_brand: StringIdentifies the CPU. If you have a mixture of different CPUs, this will be a comma separated list of the different CPUs
fingerprint: StringAdditional metadata hash(es) that can identify the running machine. For example, when running in AWS, the instance-id will be included.
online_since: DateTime<Utc>The date/time at which the process was last started
process_kind: StringWhich process is running. eg: kumod vs tsa-daemon vs. proxy-server.
version: StringThe version of KumoMTA that is running