pub struct SuspendReadyQueueV1ListEntry {
pub id: Uuid,
pub name: String,
pub reason: String,
pub duration: Duration,
pub expires: DateTime<Utc>,
}Fields
id: UuidThe id for the suspension. Can be used to cancel the suspension.
name: StringThe name of the ready queue that is suspended
reason: StringThe reason for the suspension
duration: Durationhow long until this suspension expires and is automatically removed
expires: DateTime<Utc>The time at which the suspension will expire